# Generated by Django 2.0 on 2018-01-23 17:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0002_auto_20180123_1740'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='res',
            field=models.CharField(max_length=10000, null=True),
        ),
    ]
