# Generated by Django 2.0 on 2018-01-24 10:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0004_auto_20180123_1756'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='transaction',
            name='tx',
        ),
    ]
