# Generated by Django 2.0 on 2018-01-24 13:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0006_transaction_tx'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='broadcaster',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='transaction',
            name='network',
            field=models.CharField(default='dark', max_length=50),
        ),
    ]
