# Generated by Django 2.0 on 2018-01-23 17:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0003_transaction_res'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='tx_id',
            field=models.CharField(max_length=100, null=True, unique=True),
        ),
    ]
