# Generated by Django 2.0 on 2018-02-03 16:31

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0008_auto_20180124_1342'),
    ]

    operations = [
        migrations.CreateModel(
            name='Lock',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('job_name', models.CharField(blank=True, max_length=100, unique=True)),
                ('locked', models.BooleanField(default=False)),
            ],
        ),
        migrations.AlterModelOptions(
            name='transaction',
            options={'ordering': ['-created', 'confirmations']},
        ),
        migrations.AddField(
            model_name='transaction',
            name='created',
            field=models.DateTimeField(default=datetime.datetime.now),
        ),
    ]
