# Generated by Django 2.0 on 2018-02-03 16:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0009_auto_20180203_1631'),
    ]

    operations = [
        migrations.RenameField(
            model_name='lock',
            old_name='job_name',
            new_name='name',
        ),
    ]
