# Generated by Django 2.0 on 2018-01-24 10:50

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0005_remove_transaction_tx'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='tx',
            field=django.contrib.postgres.fields.jsonb.JSONField(default={'default': 1}),
            preserve_default=False,
        ),
    ]
