# Generated by Django 2.0 on 2018-01-24 13:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ark', '0007_auto_20180124_1311'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='desc',
            field=models.CharField(max_length=1000, null=True),
        ),
    ]
